@@ -2,21 +2,28 @@
 use byteorder::{BigEndian, ByteOrder, LittleEndian};
 
 use bytes::{BytesEncoder, CopyableBytesDecoder};
-use {ByteCount, Decode, Encode, Eos, ErrorKind, ExactBytesEncode, Result};
+use {ByteCount, Decode, Encode, Eos, ErrorKind, Result, SizedEncode};
 
 macro_rules! impl_decode {
     ($ty:ty, $item:ty) => {
         impl Decode for $ty {
             type Item = $item;
 
-            fn decode(&mut self, buf: &[u8], eos: Eos) -> Result<(usize, Option<Self::Item>)> {
-                let (size, item) = track!(self.0.decode(buf, eos))?;
-                Ok((size, item.map(Self::decode_item)))
+            fn decode(&mut self, buf: &[u8], eos: Eos) -> Result<usize> {
+                track!(self.0.decode(buf, eos))
+            }
+
+            fn finish_decoding(&mut self) -> Result<Self::Item> {
+                track!(self.0.finish_decoding()).map(Self::decode_item)
             }
 
             fn requiring_bytes(&self) -> ByteCount {
                 self.0.requiring_bytes()
             }
+
+            fn is_idle(&self) -> bool {
+                self.0.is_idle()
+            }
         }
     };
 }
@@ -44,7 +51,7 @@ macro_rules! impl_encode {
                 self.0.is_idle()
             }
         }
-        impl ExactBytesEncode for $ty {
+        impl SizedEncode for $ty {
             fn exact_requiring_bytes(&self) -> u64 {
                 self.0.exact_requiring_bytes()
             }
