@@ -43,9 +43,8 @@ extern crate serde_json;
 extern crate trackable;
 
 pub use byte_count::ByteCount;
-pub use chain::{StartDecoderChain, StartEncoderChain};
 pub use decode::{Decode, DecodeExt};
-pub use encode::{Encode, EncodeExt, ExactBytesEncode};
+pub use encode::{Encode, EncodeExt, SizedEncode};
 pub use eos::Eos;
 pub use error::{Error, ErrorKind};
 
@@ -62,11 +61,10 @@ pub mod io;
 pub mod json_codec;
 pub mod marker;
 pub mod monolithic;
+pub mod padding;
 pub mod tuple;
-pub mod value;
 
 mod byte_count;
-mod chain;
 mod decode;
 mod encode;
 mod eos;
